@@ -195,7 +195,7 @@ this is in vCal 1.0 mode.
 sub _value_as_string {
     my $self = shift;
     my $key = shift;
-    my $value = $self->value();
+    my $value = $self->value() || '';
     
     unless ($self->vcal10) {
         $value =~ s/\\/\\/gs;
